/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2014 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.annotation;

import java.util.List;

import org.fortiss.tooling.base.model.element.IAnnotatedSpecification;
import org.fortiss.tooling.base.model.element.IModelElement;

/**
 * Class for an annotation entry in the annotation view table
 * 
 * @author eder
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating RED Hash:
 */
public class AnnotationEntry<T extends IAnnotatedSpecification> {

	/** Model Element */
	private IModelElement modelElement;

	/** Specification of the model element */
	private IAnnotatedSpecification specification;

	/** Value Provider to handle the specification */
	private IAnnotationValueProvider<T> valueProvider;

	/** Constructor */
	public AnnotationEntry(IModelElement modelElement, IAnnotatedSpecification specification,
			IAnnotationValueProvider<T> valueProvider) {
		this.modelElement = modelElement;
		this.specification = specification;
		this.valueProvider = valueProvider;
	}

	/** Returns the string representaion of the annotation value */
	public String getSpecificationValue() {
		return valueProvider.getValue((T)specification);
	}

	public List<String> getFixedSpecifiactionValues() {
		return valueProvider.getFixedValues();
	}

	public void setSpecificationValue(String value) {
		valueProvider.setValue(value, (T)specification);
	}

	/** Returns modelElement. */
	public IModelElement getModelElement() {
		return modelElement;
	}

	/** Returns specification. */
	public IAnnotatedSpecification getSpecification() {
		return specification;
	}

	/** Returns the annotation name */
	public String getAnnotationName() {
		return valueProvider.getAnnotationName();
	}

	/** Returns the class of the specification */
	public Class<IAnnotatedSpecification> getSpecificationClass() {
		return (Class<IAnnotatedSpecification>)specification.getClass();
	}
}
